@@ -2,11 +2,12 @@ package Alien::Build::Plugin::Core::CleanInstall;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use Path::Tiny ();
 
 # ABSTRACT: Implementation for clean_install hook.
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.33'; # VERSION
 
 
 sub init
@@ -52,7 +53,7 @@ Alien::Build::Plugin::Core::CleanInstall - Implementation for clean_install hook
 
 =head1 VERSION
 
-version 2.26
+version 2.33
 
 =head1 SYNOPSIS
 
@@ -126,6 +127,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
