@@ -2,11 +2,12 @@ package Alien::Build::Plugin::Decode::DirListingFtpcopy;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use File::Basename ();
 
 # ABSTRACT: Plugin to extract links from a directory listing using ftpcopy
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.33'; # VERSION
 
 
 sub init
@@ -58,7 +59,7 @@ Alien::Build::Plugin::Decode::DirListingFtpcopy - Plugin to extract links from a
 
 =head1 VERSION
 
-version 2.26
+version 2.33
 
 =head1 SYNOPSIS
 
@@ -141,6 +142,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
